@@ -21,15 +21,28 @@
 
 inline KAboutData* kigAboutData( const char* name, const char* iname )
 {
-  const char* version = "v0.3";
+  const char* version = "v0.4.0";
   const char* description = I18N_NOOP( "KDE Interactive Geometry" );
 
   KAboutData* tmp = new KAboutData( name, iname, version,
 				   description, KAboutData::License_GPL,
 				   "(C) 2002, Dominique Devriese");
-  tmp->addAuthor("Dominique Devriese", I18N_NOOP("Coding"),
+  tmp->addAuthor("Dominique Devriese",
+                 I18N_NOOP("Original author, maintenance, design and lots of code."),
 		  "devriese@kde.org" );
 
+  tmp->addCredit("Maurizio Paolini",
+		 I18N_NOOP( "Did the more math intensive work all around kig, "
+                            "most importantly conics, cubics and transformations "
+                            "support." ),
+		 "paolini@dmf.bs.unicatt.it");
+
+  tmp->addCredit( "Franco Pasquarelli",
+                  I18N_NOOP( "Helped with the implementation of the Locus object, "
+                             "there's some math involved in doing it right, and "
+                             "Franco basically wrote the difficult parts for me." ),
+                  "pasqui@dmf.bs.unicatt.it" );
+
   tmp->addCredit("Marc Bartsch",
 		  I18N_NOOP("Author of KGeo, where i got inspiration, "
 			    "some source, and most of the artwork from"),
@@ -40,14 +53,6 @@ inline KAboutData* kigAboutData( const char* name, const char* iname )
 			    "source of inspiration for Kig"),
 		  "ibaran@mit.edu");
 
-  tmp->addCredit("Maurizio Paolini",
-		 I18N_NOOP( "Wrote the radical line and the circle-line "
-                            "intersection as a patch for kgeo, which i "
-                            "ported to kig. Gave me some cool ideas on the "
-                            "object system, and did some really _great_ work "
-                            "on Kig's Conic support." ),
-		 "paolini@dmf.bs.unicatt.it");
-
   tmp->addCredit("Christophe Devriese",
                  I18N_NOOP( "My brother, I got him to write the algorithm for "
                             "calculating the center of the circle with three "
