@@ -55,11 +55,13 @@ class KigWidget : public QWidget
   KigView* mview;
 
   // we reimplement these from QWidget to suit our needs
-  void mousePressEvent (QMouseEvent* e);
-  void mouseMoveEvent (QMouseEvent* e);
-  void mouseReleaseEvent (QMouseEvent* e);
-  void paintEvent (QPaintEvent* e);
-  void resizeEvent(QResizeEvent*);
+  void mousePressEvent( QMouseEvent* e );
+  void mouseMoveEvent( QMouseEvent* e );
+  void mouseReleaseEvent( QMouseEvent* e );
+  void paintEvent( QPaintEvent* e );
+  void wheelEvent( QWheelEvent* e );
+  void resizeEvent( QResizeEvent* );
+  QSize sizeHint() const;
 
   // this is called to match a rect's dimensions to the dimensions of
   // the window before we set mViewRect to it.  This is done cause we
@@ -72,11 +74,10 @@ class KigWidget : public QWidget
   friend class KigMode;
   friend class NormalMode;
   friend class MovingModeBase;
-  friend class StdConstructionMode;
-  friend class PointConstructionMode;
+  friend class ConstructMode;
+  friend class PointConstructMode;
   friend class DefineMacroMode;
   friend class DragRectMode;
-  friend class SelectionModeBase;
 
   // what do the still objects look like
   // wondering if this is appropriate, maybe it should be part of
@@ -214,6 +215,7 @@ public:
   const ScreenInfo& screenInfo() const;
 
   KigWidget* realWidget();
+  void scrollVertical( int delta );
 
 public slots:
   void updateScrollBars();
