@@ -24,6 +24,9 @@
 #include <cmath>
 
 #include <kdebug.h>
+#include <knumvalidator.h>
+#include <klineeditdlg.h>
+#include <klocale.h>
 
 Coordinate calcPointOnPerpend( const LineData& l, const Coordinate& t )
 {
@@ -232,8 +235,8 @@ void calcRayBorderPoints( const double xa, const double ya, double& xb,
   kdError() << k_funcinfo << "damn" << endl;
 };
 
-bool isOnLine( const Coordinate o, const Coordinate a,
-               const Coordinate b, const double fault )
+bool isOnLine( const Coordinate& o, const Coordinate& a,
+               const Coordinate& b, const double fault )
 {
   double x1 = a.x;
   double y1 = a.y;
@@ -256,8 +259,8 @@ bool isOnLine( const Coordinate o, const Coordinate a,
   // homogeneous ones, so all z's equal 1
 };
 
-bool isOnSegment( const Coordinate o, const Coordinate a,
-                  const Coordinate b, const double fault )
+bool isOnSegment( const Coordinate& o, const Coordinate& a,
+                  const Coordinate& b, const double fault )
 {
   return isOnLine( o, a, b, fault )
     // not too far to the right
@@ -270,8 +273,8 @@ bool isOnSegment( const Coordinate o, const Coordinate a,
     && ( o.y - kigMax (a.y, b.y) < fault );
 };
 
-bool isOnRay( const Coordinate o, const Coordinate a,
-              const Coordinate b, const double fault )
+bool isOnRay( const Coordinate& o, const Coordinate& a,
+              const Coordinate& b, const double fault )
 {
   return isOnLine( o, a, b, fault )
     // not too far in front of a horizontally..
@@ -295,7 +298,7 @@ const Coordinate calcMirrorPoint( const LineData& l,
 const Coordinate calcCircleLineIntersect( const Coordinate& c,
                                           const double sqr,
                                           const LineData& l,
-                                          bool side, bool& valid )
+                                          int side, bool& valid )
 {
   Coordinate proj = calcPointProjection( c, l );
   Coordinate hvec = proj - c;
@@ -313,7 +316,7 @@ const Coordinate calcCircleLineIntersect( const Coordinate& c,
     valid = true;
     double l = sqrt( sql );
     lvec = lvec.normalize( l );
-    lvec *= side ? 1 : -1;
+    lvec *= side;
 
     return proj + lvec;
   };
@@ -373,3 +376,22 @@ Coordinate calcCircleRadicalStartPoint( const Coordinate& ca, const Coordinate&
   return m + direc;
 };
 
+double getDoubleFromUser( const QString& caption, const QString& label, double value,
+                          QWidget* parent, bool* ok, double min, double max, int decimals )
+{
+#ifdef KIG_USE_KDOUBLEVALIDATOR
+  KDoubleValidator vtor( min, max, decimals, 0, 0 );
+#else
+  KFloatValidator vtor( min, max, (QWidget*) 0, 0 );
+#endif
+  QString input =
+    KLineEditDlg::getText( caption, label,
+                           KGlobal::locale()->formatNumber( value, decimals ),
+                           ok, parent, &vtor );
+  bool myok = true;
+  double ret = KGlobal::locale()->readNumber( input, &myok );
+  if ( ! myok )
+    ret = input.toDouble( & myok );
+  if ( ok ) *ok = myok;
+  return ret;
+};
