@@ -27,20 +27,36 @@
 
 #include <qptrlist.h>
 #include <qrect.h>
+#include <kdeversion.h>
 
 #include <vector>
+#include <assert.h>
+
+#ifdef KDE_IS_VERSION
+#if KDE_IS_VERSION( 3, 1, 0 )
+#define KIG_USE_KDOUBLEVALIDATOR
+#else
+#undef KIG_USE_KDOUBLEVALIDATOR
+#endif
+#else
+#undef KIG_USE_KDOUBLEVALIDATOR
+#endif
 
 /**
  * Here, we define some algorithms which we need in
  * various places...
  */
 
+double getDoubleFromUser( const QString& caption, const QString& label, double value,
+                          QWidget* parent, bool* ok, double min, double max, int decimals );
+
 // this class represents the data needed for defining a line.
 class LineData {
 public:
   Coordinate a;
   Coordinate b;
   const Coordinate dir() const { return b - a; };
+  double length() const { return ( b - a ).length(); };
   LineData() : a(), b() {};
   LineData( const Coordinate& na, const Coordinate& nb ) : a( na ), b( nb ) {};
 };
@@ -85,15 +101,15 @@ Coordinate calcIntersectionPoint( const LineData& l, const LineData& m );
  * this calcs the intersection points of the circle with center c and
  * radius sqrt( r ), and the line l.  As a circle and a
  * line have two intersection points, side tells us which one we
- * need...  If the line and the circle have no intersection, valid is
- * set to false, otherwise to true...
+ * need...  It should be 1 or -1.  If the line and the circle have no
+ * intersection, valid is set to false, otherwise to true...
  * Note that sqr is the _square_ of the radius.  We do this to avoid
  * rounding errors...
  */
 const Coordinate calcCircleLineIntersect( const Coordinate& c,
                                           const double sqr,
                                           const LineData& l,
-                                          bool side,
+                                          int side,
                                           bool& valid );
 
 /**
@@ -144,19 +160,19 @@ const Coordinate calcMirrorPoint( const LineData& l,
  * is o on the line defined by point a and point b ?
  * fault is the allowed difference...
  */
-bool isOnLine( const Coordinate o, const Coordinate a,
-               const Coordinate b, const double fault );
+bool isOnLine( const Coordinate& o, const Coordinate& a,
+               const Coordinate& b, const double fault );
 
 /**
  * is o on the segment defined by point a and point b ?
  * this calls isOnLine(), but also checks if o is "between" a and b...
  * fault is the allowed difference...
  */
-bool isOnSegment( const Coordinate o, const Coordinate a,
-                  const Coordinate b, const double fault );
+bool isOnSegment( const Coordinate& o, const Coordinate& a,
+                  const Coordinate& b, const double fault );
 
-bool isOnRay( const Coordinate o, const Coordinate a,
-              const Coordinate b, const double fault );
+bool isOnRay( const Coordinate& o, const Coordinate& a,
+              const Coordinate& b, const double fault );
 
 Coordinate calcCircleRadicalStartPoint( const Coordinate& ca,
                                         const Coordinate& cb,
